@@ -18,6 +18,7 @@ import logging
 import os
 from pkg_resources import parse_version, iter_entry_points
 from typing import List, Union
+import weakref
 
 # Third-party imports
 from qtpy.QtCore import QMutex, QMutexLocker, QTimer, Slot, Signal
@@ -69,8 +70,8 @@ class CompletionPlugin(SpyderPluginV2):
 
     NAME = 'completions'
     CONF_SECTION = 'completions'
-    REQUIRES = [Plugins.Preferences]
-    OPTIONAL = [Plugins.Application, Plugins.StatusBar, Plugins.MainMenu]
+    REQUIRES = [Plugins.Preferences, Plugins.MainInterpreter]
+    OPTIONAL = [Plugins.StatusBar, Plugins.MainMenu]
 
     CONF_FILE = False
 
@@ -123,7 +124,7 @@ class CompletionPlugin(SpyderPluginV2):
         New PythonPath settings.
     """
 
-    sig_main_interpreter_changed = Signal()
+    sig_interpreter_changed = Signal()
     """
     This signal is used to report changes on the main Python interpreter.
     """
@@ -234,6 +235,12 @@ class CompletionPlugin(SpyderPluginV2):
         # entrypoints
         for entry_point in iter_entry_points(COMPLETION_ENTRYPOINT):
             try:
+                # This absolutely ensures that the Kite provider won't be
+                # loaded. For instance, it can happen when you have an older
+                # Spyder version installed, but you're running it with
+                # bootstrap.
+                if 'kite' in entry_point.name:
+                    continue
                 logger.debug(f'Loading entry point: {entry_point}')
                 Provider = entry_point.resolve()
                 self._instantiate_and_register_provider(Provider)
@@ -262,9 +269,11 @@ class CompletionPlugin(SpyderPluginV2):
                  'linting requests sent to multiple providers.')
 
     def get_icon(self):
-        return self.create_icon('lspserver')
+        return self.create_icon('completions')
 
     def on_initialize(self):
+        self.sig_interpreter_changed.connect(self.update_completion_status)
+
         if self.main:
             self.main.sig_pythonpath_changed.connect(
                 self.sig_pythonpath_changed)
@@ -285,18 +294,25 @@ class CompletionPlugin(SpyderPluginV2):
         preferences = self.get_plugin(Plugins.Preferences)
         preferences.register_plugin_preferences(self)
 
+    @on_plugin_available(plugin=Plugins.MainInterpreter)
+    def on_maininterpreter_available(self):
+        maininterpreter = self.get_plugin(Plugins.MainInterpreter)
+        mi_container = maininterpreter.get_container()
+
+        # connect signals
+        self.completion_status.sig_open_preferences_requested.connect(
+            mi_container.sig_open_preferences_requested)
+
+        mi_container.sig_interpreter_changed.connect(
+            self.sig_interpreter_changed)
+
     @on_plugin_available(plugin=Plugins.StatusBar)
     def on_statusbar_available(self):
         container = self.get_container()
         self.statusbar = self.get_plugin(Plugins.StatusBar)
         for sb in container.all_statusbar_widgets():
             self.statusbar.add_status_widget(sb)
-
-    @on_plugin_available(plugin=Plugins.Application)
-    def on_application_available(self):
-        application = self.get_plugin(Plugins.Application)
-        self.sig_restart_requested.connect(
-            application.sig_restart_requested)
+        self.statusbar.add_status_widget(self.completion_status)
 
     @on_plugin_available(plugin=Plugins.MainMenu)
     def on_mainmenu_available(self):
@@ -315,6 +331,14 @@ class CompletionPlugin(SpyderPluginV2):
         preferences = self.get_plugin(Plugins.Preferences)
         preferences.deregister_plugin_preferences(self)
 
+    @on_plugin_teardown(plugin=Plugins.MainInterpreter)
+    def on_maininterpreter_teardown(self):
+        maininterpreter = self.get_plugin(Plugins.MainInterpreter)
+        mi_container = maininterpreter.get_container()
+
+        mi_container.sig_interpreter_changed.disconnect(
+            self.sig_interpreter_changed)
+
     @on_plugin_teardown(plugin=Plugins.StatusBar)
     def on_statusbar_teardown(self):
         container = self.get_container()
@@ -451,8 +475,12 @@ class CompletionPlugin(SpyderPluginV2):
             provider.STATUS_BAR_CLASSES, provider_name)
         if plugin_loaded:
             for id_ in widgets_ids:
-                currrent_widget = container.statusbar_widgets[id_]
-                self.statusbar.add_status_widget(currrent_widget)
+                current_widget = container.statusbar_widgets[id_]
+                # Validation to check for status bar registration before trying
+                # to add a widget.
+                # See spyder-ide/spyder#16997
+                if id_ not in self.statusbar.get_status_widgets():
+                    self.statusbar.add_status_widget(current_widget)
 
     def unregister_statusbar(self, provider_name):
         """
@@ -463,11 +491,44 @@ class CompletionPlugin(SpyderPluginV2):
         provider_name: str
             Name of the provider that is going to delete statusbar widgets.
         """
+        container = self.get_container()
         provider_keys = self.get_container().get_provider_statusbar_keys(
             provider_name)
         for id_ in provider_keys:
-            self.get_container().remove_statusbar_widget(id_)
-            self.statusbar.remove_status_widget(id_)
+            # Validation to check for status bar registration before trying
+            # to remove a widget.
+            # See spyder-ide/spyder#16997
+            if id_ in container.statusbar_widgets:
+                self.get_container().remove_statusbar_widget(id_)
+                self.statusbar.remove_status_widget(id_)
+
+    @property
+    def completion_status(self):
+        return self.get_container().completion_status
+
+    @Slot()
+    def update_completion_status(self):
+        maininterpreter = self.get_plugin(Plugins.MainInterpreter)
+        mi_status = maininterpreter.get_container().interpreter_status
+
+        value = mi_status.value
+        tool_tip = mi_status._interpreter
+
+        if '(' in value:
+            value = value.split('(')[0]
+
+        if ':' in value:
+            kind, name = value.split(':')
+        else:
+            kind, name = value, ''
+        kind = kind.strip()
+        name = name.strip()
+
+        new_value = f'Completions: {kind}'
+        if name:
+            new_value += f'({name})'
+
+        self.completion_status.update_status(new_value, tool_tip)
 
     # -------- Completion provider initialization redefinition wrappers -------
     def gather_providers_and_configtabs(self):
@@ -744,6 +805,8 @@ class CompletionPlugin(SpyderPluginV2):
         container = self.get_container()
 
         provider_instance.sig_provider_ready.connect(self.provider_available)
+        provider_instance.sig_stop_completions.connect(
+            self.sig_stop_completions)
         provider_instance.sig_response_ready.connect(self.receive_response)
         provider_instance.sig_exception_occurred.connect(
             self.sig_exception_occurred)
@@ -760,7 +823,7 @@ class CompletionPlugin(SpyderPluginV2):
 
         self.sig_pythonpath_changed.connect(
             provider_instance.python_path_update)
-        self.sig_main_interpreter_changed.connect(
+        self.sig_interpreter_changed.connect(
             provider_instance.main_interpreter_changed)
 
     def _instantiate_and_register_provider(
@@ -797,11 +860,11 @@ class CompletionPlugin(SpyderPluginV2):
             server_status = self.language_status[language]
             server_status[provider_name] = False
 
-    def start_all_providers(self):
+    def start_all_providers(self, force=False):
         """Start all detected completion providers."""
         for provider_name in self.providers:
             provider_info = self.providers[provider_name]
-            if provider_info['status'] == self.STOPPED:
+            if provider_info['status'] == self.STOPPED or force:
                 provider_enabled = self.get_conf(
                     ('enabled_providers', provider_name), True)
                 if provider_enabled:
@@ -952,7 +1015,7 @@ class CompletionPlugin(SpyderPluginV2):
         self.requests[req_id] = {
             'language': language,
             'req_type': req_type,
-            'response_instance': req['response_instance'],
+            'response_instance': weakref.ref(req['response_instance']),
             'sources': {},
             'timed_out': False,
         }
@@ -1171,7 +1234,7 @@ class CompletionPlugin(SpyderPluginV2):
         """
         request_responses = self.requests[req_id]
         req_type = request_responses['req_type']
-        response_instance = id(request_responses['response_instance'])
+        response_instance = id(request_responses['response_instance']())
         do_send = True
 
         # This is necessary to prevent sending completions for old requests
@@ -1180,7 +1243,7 @@ class CompletionPlugin(SpyderPluginV2):
             max_req_id = max(
                 [key for key, item in self.requests.items()
                  if item['req_type'] == req_type
-                 and id(item['response_instance']) == response_instance]
+                 and id(item['response_instance']()) == response_instance]
                 or [-1])
             do_send = (req_id == max_req_id)
 
@@ -1198,7 +1261,7 @@ class CompletionPlugin(SpyderPluginV2):
         """
         req_type = request_responses['req_type']
         req_id_responses = request_responses['sources']
-        response_instance = request_responses['response_instance']
+        response_instance = request_responses['response_instance']()
         logger.debug('Gather responses for {0}'.format(req_type))
 
         if req_type == CompletionRequestTypes.DOCUMENT_COMPLETION:
@@ -1207,7 +1270,8 @@ class CompletionPlugin(SpyderPluginV2):
             responses = self.gather_responses(req_type, req_id_responses)
 
         try:
-            response_instance.handle_response(req_type, responses)
+            if response_instance:
+                response_instance.handle_response(req_type, responses)
         except RuntimeError:
             # This is triggered when a codeeditor instance has been
             # removed before the response can be processed.
