@@ -9,15 +9,19 @@
 """Tests for the Editor plugin."""
 
 # Standard library imports
+import os
 import os.path as osp
 import shutil
 
 # Third party imports
+from qtpy.QtCore import Qt
 import pytest
 
 # Local imports
 from spyder.plugins.editor.utils.autosave import AutosaveForPlugin
+from spyder.plugins.editor.widgets import editor as editor_module
 from spyder.plugins.editor.widgets.codeeditor import CodeEditor
+from spyder.utils.sourcecode import get_eol_chars, get_eol_chars_from_os_name
 
 
 # =============================================================================
@@ -57,6 +61,36 @@ def test_setup_open_files(editor_plugin_open_files, last_focused_filename,
     assert filenames == expected_filenames
 
 
+def test_restore_open_files(qtbot, editor_plugin_open_files):
+    """Test restoring of opened files without Projects plugin"""
+    editor_factory = editor_plugin_open_files
+    editor, expected_filenames, expected_current_filename = (
+        editor_factory(None, None))
+
+    # Pre-condition: Projects plugin is disabled
+    assert editor.projects is None
+
+    # `expected_filenames` is modified. A copy is required because
+    # `expected_filenames` and `editor.get_option("filesnames")` are the same
+    # object.
+    expected_filenames = expected_filenames.copy()
+    assert expected_filenames is not editor.get_option("filenames")
+    for i in range(2):
+        filename = expected_filenames.pop()
+        editor.close_file_from_name(filename)
+
+    # Close editor and check that opened files are saved
+    editor.closing_plugin()
+    filenames = [osp.normcase(f) for f in editor.get_option("filenames")]
+    assert filenames == expected_filenames
+
+    # “Re-open” editor and check the opened files are restored
+    editor.setup_open_files(close_previous_files=True)
+    filenames = editor.get_current_editorstack().get_filenames()
+    filenames = [osp.normcase(f) for f in filenames]
+    assert filenames == expected_filenames
+
+
 def test_setup_open_files_cleanprefs(editor_plugin_open_files):
     """Test that Editor successfully opens files if layout is not defined.
 
@@ -223,16 +257,13 @@ def test_go_to_prev_next_cursor_position(editor_plugin, python_files):
     filenames, tmpdir = python_files
     editorstack = editor_plugin.get_current_editorstack()
 
-    expected_cursor_pos_history = []
-    assert editor_plugin.cursor_pos_history == expected_cursor_pos_history
-
+    expected_cursor_undo_history = []
+    assert editor_plugin.cursor_undo_history == expected_cursor_undo_history
     # Load the Python test files (4).
     editor_plugin.load(filenames)
     # Open a new file.
     editor_plugin.new()
     # Go to the third file.
-    cur_editor = editorstack.get_current_editor()
-    cur_line, cur_col = cur_editor.get_cursor_line_column()
     editorstack.set_stack_index(2)
     # Move the cursor within the third file. Note that this new position is
     # not added to the cursor position history.
@@ -241,20 +272,22 @@ def test_go_to_prev_next_cursor_position(editor_plugin, python_files):
     # results because those returned by the python_files fixture are
     # normalized, so this would cause issues when assessing the results.
     filenames = editor_plugin.get_filenames()
-    expected_cursor_pos_history = [
-        (filenames[0], 0, 0, 0),
-        (filenames[-1], len(editorstack.data[-1].get_source_code()),
-         cur_line, cur_col),
-        (filenames[2], 5, 0, 5)
+    expected_cursor_undo_history = [
+        (filenames[0], 0),
+        (filenames[-1], len(editorstack.data[-1].get_source_code())),
+        (filenames[2], 5)
         ]
-    assert editor_plugin.cursor_pos_history == expected_cursor_pos_history
+    for history, expected_history in zip(editor_plugin.cursor_undo_history,
+                                         expected_cursor_undo_history):
+        assert history[0] == expected_history[0]
+        assert history[1].position() == expected_history[1]
 
     # Navigate to previous and next cursor positions.
 
     # The last entry in the cursor position history is overridden by the
     # current cursor position when going to previous or next cursor position,
-    # so we need to update the last item of the expected_cursor_pos_history.
-    expected_cursor_pos_history[-1] = (filenames[2], 5, 0, 5)
+    # so we need to update the last item of the expected_cursor_undo_history.
+    expected_cursor_undo_history[-1] = (filenames[2], 5)
 
     cursor_index_moves = [-1, 1, 1, -1, -1, -1, 1, -1]
     expected_cursor_pos_indexes = [1, 2, 2, 1, 0, 0, 1, 0]
@@ -263,15 +296,19 @@ def test_go_to_prev_next_cursor_position(editor_plugin, python_files):
             editor_plugin.go_to_previous_cursor_position()
         elif move == 1:
             editor_plugin.go_to_next_cursor_position()
-
-        assert editor_plugin.cursor_pos_index == index
-        cur_line, cur_col = (
-            editorstack.get_current_editor().get_cursor_line_column())
+        assert len(editor_plugin.cursor_undo_history) - 1 == index
         assert (editor_plugin.get_current_filename(),
-                editor_plugin.get_current_editor().get_position('cursor'),
-                cur_line, cur_col
-                ) == expected_cursor_pos_history[index]
-    assert editor_plugin.cursor_pos_history == expected_cursor_pos_history
+                editor_plugin.get_current_editor().get_position('cursor')
+                ) == expected_cursor_undo_history[index]
+
+    for history, expected_history in zip(editor_plugin.cursor_undo_history,
+                                         expected_cursor_undo_history[:1]):
+        assert history[0] == expected_history[0]
+        assert history[1].position() == expected_history[1]
+    for history, expected_history in zip(editor_plugin.cursor_redo_history,
+                                         expected_cursor_undo_history[:0:-1]):
+        assert history[0] == expected_history[0]
+        assert history[1].position() == expected_history[1]
 
     # So we are now expected to be at index 0 in the cursor position history.
     # From there, we go to the fourth file.
@@ -280,9 +317,14 @@ def test_go_to_prev_next_cursor_position(editor_plugin, python_files):
     # We expect that our last action caused the cursor position history to
     # be stripped from the current cursor position index and that the
     # new cursor position is added at the end of the cursor position history.
-    expected_cursor_pos_history = expected_cursor_pos_history[:1]
-    expected_cursor_pos_history.append((filenames[3], 0, 0, 0))
-    assert editor_plugin.cursor_pos_history == expected_cursor_pos_history
+    expected_cursor_undo_history = expected_cursor_undo_history[:1]
+    expected_cursor_undo_history.append((filenames[3], 0))
+
+    for history, expected_history in zip(editor_plugin.cursor_undo_history,
+                                         expected_cursor_undo_history):
+        assert history[0] == expected_history[0]
+        assert history[1].position() == expected_history[1]
+    assert editor_plugin.cursor_redo_history == []
 
 
 def test_open_and_close_lsp_requests(editor_plugin_open_files, mocker):
@@ -328,5 +370,84 @@ def test_open_and_close_lsp_requests(editor_plugin_open_files, mocker):
     assert CodeEditor.notify_close.call_count == 2
 
 
+@pytest.mark.parametrize('os_name', ['nt', 'mac', 'posix'])
+def test_toggle_eol_chars(editor_plugin, python_files, qtbot, os_name):
+    """
+    Check that changing eol chars from the 'Convert end-of-line characters'
+    menu works as expected.
+    """
+    filenames, tmpdir = python_files
+    editorstack = editor_plugin.get_current_editorstack()
+
+    # Load a test file
+    fname = filenames[0]
+    editor_plugin.load(fname)
+    qtbot.wait(500)
+    codeeditor = editor_plugin.get_current_editor()
+
+    # Change to a different eol, save and check that file has the right eol.
+    editor_plugin.toggle_eol_chars(os_name, True)
+    assert codeeditor.document().isModified()
+    editorstack.save()
+    with open(fname, mode='r', newline='') as f:
+        text = f.read()
+    assert get_eol_chars(text) == get_eol_chars_from_os_name(os_name)
+
+
+@pytest.mark.parametrize('os_name', ['nt', 'mac', 'posix'])
+def test_save_with_preferred_eol_chars(editor_plugin, python_files, qtbot,
+                                       os_name):
+    """Check that saving files with preferred eol chars works as expected."""
+    filenames, tmpdir = python_files
+    editorstack = editor_plugin.get_current_editorstack()
+    eol_lookup = {'posix': 'LF', 'nt': 'CRLF', 'mac': 'CR'}
+
+    # Set options
+    editor_plugin.set_option('convert_eol_on_save', True)
+    editor_plugin.set_option('convert_eol_on_save_to', eol_lookup[os_name])
+    editor_plugin.apply_plugin_settings(
+        {'convert_eol_on_save', 'convert_eol_on_save_to'}
+    )
+
+    # Load a test file
+    fname = filenames[0]
+    editor_plugin.load(fname)
+    qtbot.wait(500)
+    codeeditor = editor_plugin.get_current_editor()
+
+    # Set file as dirty, save it and check that it has the right eol.
+    codeeditor.document().setModified(True)
+    editorstack.save()
+    with open(fname, mode='r', newline='') as f:
+        text = f.read()
+    assert get_eol_chars(text) == get_eol_chars_from_os_name(os_name)
+
+
+def test_save_with_os_eol_chars(editor_plugin, mocker, qtbot, tmpdir):
+    """Check that saving new files uses eol chars according to OS."""
+    editorstack = editor_plugin.get_current_editorstack()
+
+    # Mock output of save file dialog.
+    fname = osp.join(tmpdir, 'test_eol_chars.py')
+    mocker.patch.object(editor_module, 'getsavefilename')
+    editor_module.getsavefilename.return_value = (fname, '')
+
+    # Load new, empty file
+    editor_plugin.new()
+    qtbot.wait(500)
+    codeeditor = editor_plugin.get_current_editor()
+
+    # Write some blank lines on it.
+    for __ in range(3):
+        qtbot.keyClick(codeeditor, Qt.Key_Return)
+
+    # Save file and check that it has the right eol.
+    editorstack.save()
+    with open(fname, mode='r', newline='') as f:
+        text = f.read()
+
+    assert get_eol_chars(text) == os.linesep
+
+
 if __name__ == "__main__":
     pytest.main(['-x', osp.basename(__file__), '-vv', '-rw'])
