@@ -14,7 +14,7 @@ from unittest.mock import patch
 from flaky import flaky
 import pytest
 from qtpy.QtCore import Qt
-from qtpy.QtGui import QFont, QTextCursor, QTextFormat
+from qtpy.QtGui import QFont, QTextCursor
 
 # Local imports
 from spyder.plugins.editor.widgets.codeeditor import CodeEditor
@@ -24,26 +24,9 @@ HERE = osp.dirname(osp.realpath(__file__))
 PARENT = osp.dirname(HERE)
 
 
-# --- Fixtures
-# -----------------------------------------------------------------------------
-@pytest.fixture
-def construct_editor(qtbot):
-    """Construct editor for testing decorations."""
-    editor = CodeEditor(parent=None)
-    editor.setup_editor(
-        language='Python',
-        color_scheme='spyder/dark',
-        font=QFont("Monospace", 10),
-    )
-    editor.resize(640, 480)
-    editor.show()
-    qtbot.addWidget(editor)
-    return editor
-
-
-def test_decorations(construct_editor, qtbot):
+def test_decorations(codeeditor, qtbot):
     """Test decorations."""
-    editor = construct_editor
+    editor = codeeditor
 
     # Set random size
     editor.resize(640, random.randint(200, 500))
@@ -71,7 +54,8 @@ def test_decorations(construct_editor, qtbot):
 
     # Assert number of decorations is the one we expect.
     qtbot.wait(3000)
-    decorations = editor.decorations._decorations
+    decorations = editor.decorations._sorted_decorations()
+
     assert len(decorations) == 2 + text.count('some_variable')
 
     # Assert that selection 0 is current cell
@@ -95,7 +79,7 @@ def test_decorations(construct_editor, qtbot):
     # Clear decorations to be sure they are painted again below.
     editor.decorations.clear()
     editor.decorations._update()
-    assert editor.decorations._decorations == []
+    assert editor.decorations._sorted_decorations() == []
 
     # Move to a random place in the file and wait until decorations are
     # updated.
@@ -104,7 +88,7 @@ def test_decorations(construct_editor, qtbot):
     qtbot.wait(editor.UPDATE_DECORATIONS_TIMEOUT + 100)
 
     # Assert a new cell is painted
-    decorations = editor.decorations._decorations
+    decorations = editor.decorations._sorted_decorations()
     assert decorations[0].kind == 'current_cell'
 
 
