@@ -21,7 +21,7 @@ from qtpy.QtCore import Qt
 from qtpy.QtGui import QTextCursor
 
 # Local imports
-from spyder.config.base import get_conf_path
+from spyder.config.base import get_conf_path, running_in_ci
 from spyder.plugins.editor.widgets.editor import EditorStack
 from spyder.widgets.findreplace import FindReplace
 from spyder.py3compat import PY2
@@ -68,7 +68,7 @@ def editor_find_replace_bot(base_editor_bot, qtbot):
             'spam sausage\n'
             'spam egg')
     finfo = editor_stack.new('spam.py', 'utf-8', text)
-    find_replace = FindReplace(None, enable_replace=True)
+    find_replace = FindReplace(editor_stack, enable_replace=True)
     editor_stack.set_find_widget(find_replace)
     find_replace.set_editor(finfo.editor)
     qtbot.addWidget(editor_stack)
@@ -89,7 +89,7 @@ def editor_cells_bot(base_editor_bot, qtbot):
             '# 3 cell\n'
             '# print(3)\n')
     finfo = editor_stack.new('cells.py', 'utf-8', text)
-    find_replace = FindReplace(None, enable_replace=True)
+    find_replace = FindReplace(editor_stack, enable_replace=True)
     qtbot.addWidget(editor_stack)
     return editor_stack, finfo.editor
 
@@ -111,7 +111,7 @@ def editor_folding_bot(base_editor_bot, qtbot):
             )
     finfo = editor_stack.new('foo.py', 'utf-8', text)
 
-    find_replace = FindReplace(None, enable_replace=True)
+    find_replace = FindReplace(editor_stack, enable_replace=True)
     editor_stack.set_find_widget(find_replace)
     find_replace.set_editor(finfo.editor)
     qtbot.addWidget(editor_stack)
@@ -226,7 +226,8 @@ def test_move_multiple_lines_up(editor_bot):
     assert editor.toPlainText() == expected_new_text
 
 
-@pytest.mark.skipif(os.name == 'nt', reason="It fails on Windows")
+@pytest.mark.skipif(not sys.platform.startswith('linux'),
+                    reason="Works only on Linux")
 def test_copy_lines_down_up(editor_bot, mocker, qtbot):
     """
     Test that copy lines down and copy lines up are working as expected.
@@ -627,7 +628,7 @@ def test_tab_moves_focus_from_search_to_replace(editor_find_replace_bot,
     editor_stack, editor, finder = editor_find_replace_bot
     text = '  \nspam \nspam \nspam '
     editor.set_text(text)
-    finder.show()
+    editor_stack.show()
     finder.show_replace()
 
     qtbot.wait(100)
@@ -642,8 +643,7 @@ def test_tab_moves_focus_from_search_to_replace(editor_find_replace_bot,
 
 
 @flaky(max_runs=3)
-@pytest.mark.skipif(os.environ.get('CI', None) is not None,
-                    reason="It fails on CIs")
+@pytest.mark.skipif(running_in_ci(), reason="Fails on CIs")
 def test_tab_copies_find_to_replace(editor_find_replace_bot, qtbot):
     """Check that text in the find box is copied to the replace box on tab
     keypress. Regression test spyder-ide/spyder#4482."""
