@@ -10,15 +10,20 @@ Tests for EditorStack save methods.
 
 # Standard library imports
 import os.path as osp
+import sys
+from textwrap import dedent
 from unittest.mock import Mock
 
 # Third party imports
+from flaky import flaky
 import pytest
+from qtpy.QtCore import Qt
 
 # Local imports
+from spyder.config.base import running_in_ci
 from spyder.plugins.editor.panels import DebuggerPanel
 from spyder.plugins.editor.widgets import editor
-from spyder.plugins.outlineexplorer.widgets import OutlineExplorerWidget
+from spyder.plugins.outlineexplorer.main_widget import OutlineExplorerWidget
 
 
 # ---- Helpers
@@ -65,7 +70,7 @@ def editor_bot(base_editor_bot, request):
 @pytest.fixture
 def editor_splitter_bot(qtbot):
     """Create editor splitter."""
-    es = editor_splitter = editor.EditorSplitter(None, Mock(), [], first=True)
+    es = editor.EditorSplitter(None, Mock(), [], first=True)
     qtbot.addWidget(es)
     es.show()
     yield es
@@ -297,38 +302,88 @@ def test_save_as(editor_bot, mocker):
 
 
 @pytest.mark.show_save_dialog
-def test_save_as_with_outline(editor_bot, mocker, tmpdir):
+def test_save_as_with_outline(completions_editor, mocker, qtbot, tmpdir):
     """
-    Test EditorStack.save_as() when the outline explorer is not None.
+    Test EditorStack.save_as() when the outline explorer is active.
 
-    Regression test for spyder-ide/spyder#7754.
+    Regression test for issues spyder-ide/spyder#7754 and
+    spyder-ide/spyder#15517.
     """
-    editorstack, qtbot = editor_bot
+    file_path, editorstack, code_editor, completion_plugin = completions_editor
+    proxy = code_editor.oe_proxy
 
-    # Set and assert the initial state.
-    editorstack.tabs.setCurrentIndex(1)
-    assert editorstack.get_current_filename() == 'secondtab.py'
+    # Set outline explorer to editor stack and refresh it.
+    outline_explorer = OutlineExplorerWidget(None, None, None)
+    treewidget = outline_explorer.treewidget
+    outline_explorer.show()
+    treewidget.is_visible = True
 
-    # Add an outline explorer to the editor stack and refresh it.
-    editorstack.set_outlineexplorer(OutlineExplorerWidget(None, None, None))
+    editorstack.set_outlineexplorer(outline_explorer)
     qtbot.addWidget(editorstack.outlineexplorer)
-    for finfo in editorstack.data:
-        editorstack.outlineexplorer.register_editor(finfo.editor.oe_proxy)
+    editorstack.outlineexplorer.register_editor(proxy)
+
+    outline_explorer.start_symbol_services('python')
     editorstack.refresh()
 
+    # Add some code to the test file and save it
+    code = dedent("""
+        def foo(x):
+            return x
+
+        def bar(y):
+            return y
+    """)
+
+    code_editor.set_text(code)
+    editorstack.save(force=True)
+
+    # Notify changes
+    with qtbot.waitSignal(
+        code_editor.completions_response_signal, timeout=30000
+    ):
+        code_editor.document_did_change()
+
+    # Wait until the outline is filled
+    qtbot.waitUntil(
+        lambda: len(treewidget.editor_tree_cache[proxy.get_id()]) > 0,
+        timeout=5000
+    )
+
     # No save name.
     mocker.patch.object(editorstack, 'select_savename', return_value=None)
     assert editorstack.save_as() is False
-    assert editorstack.get_filenames() == ['foo.py', 'secondtab.py', __file__]
 
-    # Save secondtab.py as foo2.py in a tmpdir
+    # Save file as foo2.py in tmpdir
     new_filename = osp.join(tmpdir.strpath, 'foo2.py')
     editorstack.select_savename.return_value = new_filename
     assert not osp.exists(new_filename)
-    assert editorstack.save_as() is True
-    assert editorstack.get_filenames() == ['foo.py', new_filename, __file__]
+
+    # Symbols should have been requested for the renamed file, which emits the
+    # signals below.
+    with qtbot.waitSignals(
+        [proxy.sig_start_outline_spinner,
+         proxy.sig_outline_explorer_data_changed],
+        timeout=30000
+    ):
+        assert editorstack.save_as() is True
+
+    assert editorstack.get_filenames() == [new_filename]
     assert osp.exists(new_filename)
 
+    # Wait until the outline is filled
+    qtbot.waitUntil(
+        lambda: len(treewidget.editor_tree_cache[proxy.get_id()]) > 0,
+        timeout=5000
+    )
+
+    # Assert root and symbol items have the right path.
+    items = treewidget.editor_items[proxy.get_id()]
+    root_item = items.node
+
+    assert root_item.path == new_filename
+    assert items.path == new_filename
+    assert all([item.path == new_filename for item in items.children])
+
 
 def test_save_copy_as(editor_bot, mocker):
     """Test EditorStack.save_copy as()."""
@@ -452,5 +507,45 @@ def test_save_as_change_file_type(editor_bot, mocker, tmpdir):
     assert not debugger_panel.isVisible()
 
 
+@pytest.mark.slow
+@pytest.mark.order(1)
+@flaky(max_runs=5)
+@pytest.mark.skipif(running_in_ci() and sys.platform.startswith('linux'),
+                    reason="Stalls test suite with Linux on CI")
+def test_save_when_completions_are_visible(completions_editor, qtbot):
+    """
+    Test that save works when the completion widget is visible and the user
+    press the save shortcut (Ctrl+S).
+
+    Regression test for issue spyder-ide/spyder#14806.
+    """
+    file_path, editorstack, code_editor, __ = completions_editor
+    completion = code_editor.completion_widget
+    code_editor.toggle_code_snippets(False)
+
+    code_editor.set_text('some = 0\nsomething = 1\n')
+    editorstack.save(force=True)
+    cursor = code_editor.textCursor()
+    code_editor.moveCursor(cursor.End)
+
+    # Complete some -> [some, something]
+    with qtbot.waitSignal(completion.sig_show_completions,
+                          timeout=10000) as sig:
+        qtbot.keyClicks(code_editor, 'some')
+    assert "some" in [x['label'] for x in sig.args[0]]
+    assert "something" in [x['label'] for x in sig.args[0]]
+
+    # Press keyboard shortcut corresponding to save
+    qtbot.keyPress(
+        completion, Qt.Key_S, modifier=Qt.ControlModifier, delay=300)
+
+    # Assert file was saved
+    with open(file_path, 'r') as f:
+        saved_text = f.read()
+    assert saved_text == 'some = 0\nsomething = 1\nsome'
+
+    code_editor.toggle_code_snippets(True)
+
+
 if __name__ == "__main__":
     pytest.main()
