@@ -202,12 +202,6 @@ class Help(SpyderDockablePlugin):
         except SpyderAPIError:
             pass
 
-    def on_mainwindow_visible(self):
-        # Raise plugin the first time Spyder starts
-        if self.get_conf('show_first_time', default=True):
-            self.dockwidget.raise_()
-            self.set_conf('show_first_time', False)
-
     # --- Private API
     # ------------------------------------------------------------------------
     def _setup_menus(self):
