@@ -11,30 +11,38 @@ Main menu Plugin.
 # Standard library imports
 from collections import OrderedDict
 import sys
+from typing import Dict, List, Tuple, Optional, Union
 
 # Third party imports
 from qtpy.QtGui import QKeySequence
-from qtpy.QtWidgets import QMenu
 
 # Local imports
 from spyder.api.exceptions import SpyderAPIError
-from spyder.api.plugins import Plugins, SpyderPluginV2, SpyderDockablePlugin
+from spyder.api.plugin_registration.registry import PLUGIN_REGISTRY
+from spyder.api.plugins import SpyderPluginV2, SpyderDockablePlugin, Plugins
 from spyder.api.translations import get_translation
-from spyder.api.widgets.menus import MENU_SEPARATOR
-from spyder.plugins.mainmenu.api import (
-    ApplicationMenu, ApplicationMenus, HelpMenuSections)
-from spyder.utils.qthelpers import add_actions, set_menu_icons
+from spyder.api.widgets.menus import MENU_SEPARATOR, SpyderMenu
+from spyder.plugins.mainmenu.api import ApplicationMenu, ApplicationMenus
+from spyder.utils.qthelpers import set_menu_icons, SpyderAction
 
 # Localization
 _ = get_translation('spyder')
 
+# Extended typing definitions
+ItemType = Union[SpyderAction, SpyderMenu]
+ItemSectionBefore = Tuple[
+    ItemType, Optional[str], Optional[str], Optional[str]]
+ItemQueue = Dict[str, List[ItemSectionBefore]]
+
 
 class MainMenu(SpyderPluginV2):
     NAME = 'mainmenu'
     CONF_SECTION = NAME
     CONF_FILE = False
+    CAN_BE_DISABLED = False
 
-    def get_name(self):
+    @staticmethod
+    def get_name():
         return _('Main menus')
 
     def get_icon(self):
@@ -46,6 +54,11 @@ class MainMenu(SpyderPluginV2):
     def on_initialize(self):
         # Reference holder dict for the menus
         self._APPLICATION_MENUS = OrderedDict()
+
+        # Queue that contain items that are pending to add to a non-existing
+        # menu
+        self._ITEM_QUEUE = {}  # type: ItemQueue
+
         # Create Application menus using plugin public API
         # FIXME: Migrated menus need to have 'dynamic=True' (default value) to
         # work on Mac. Remove the 'dynamic' kwarg when migrating a menu!
@@ -57,7 +70,8 @@ class MainMenu(SpyderPluginV2):
         create_app_menu(ApplicationMenus.Run, _("&Run"), dynamic=False)
         create_app_menu(ApplicationMenus.Debug, _("&Debug"), dynamic=False)
         create_app_menu(ApplicationMenus.Consoles, _("C&onsoles"))
-        create_app_menu(ApplicationMenus.Projects, _("&Projects"))
+        if self.is_plugin_enabled(Plugins.Projects):
+            create_app_menu(ApplicationMenus.Projects, _("&Projects"))
         create_app_menu(ApplicationMenus.Tools, _("&Tools"))
         create_app_menu(ApplicationMenus.View, _("&View"))
         create_app_menu(ApplicationMenus.Help, _("&Help"))
@@ -67,9 +81,10 @@ class MainMenu(SpyderPluginV2):
         # and "Preferences") are located in the right place in Mac's menu
         # bar.
         # Fixes spyder-ide/spyder#14917
-        if sys.platform == 'darwin':
-            for menu in self._APPLICATION_MENUS.values():
-                menu._render()
+        # This also registers shortcuts for actions that are only in menus.
+        # Fixes spyder-ide/spyder#16061
+        for menu in self._APPLICATION_MENUS.values():
+            menu._render()
 
     # ---- Private methods
     # ------------------------------------------------------------------------
@@ -119,18 +134,19 @@ class MainMenu(SpyderPluginV2):
 
     def _hide_options_menus(self):
         """Hide options menu when menubar is pressed in macOS."""
-        for _plugin_id, plugin in self.main._PLUGINS.items():
-            if isinstance(plugin, SpyderDockablePlugin):
-                if plugin.CONF_SECTION == 'editor':
+        for plugin_name in PLUGIN_REGISTRY:
+            plugin_instance = PLUGIN_REGISTRY.get_plugin(plugin_name)
+            if isinstance(plugin_instance, SpyderDockablePlugin):
+                if plugin_instance.CONF_SECTION == 'editor':
                     editorstack = self.editor.get_current_editorstack()
                     editorstack.menu.hide()
                 else:
                     try:
                         # New API
-                        plugin.options_menu.hide()
+                        plugin_instance.options_menu.hide()
                     except AttributeError:
                         # Old API
-                        plugin._options_menu.hide()
+                        plugin_instance._options_menu.hide()
 
     def _setup_menus(self):
         """Setup menus."""
@@ -149,7 +165,8 @@ class MainMenu(SpyderPluginV2):
 
     # ---- Public API
     # ------------------------------------------------------------------------
-    def create_application_menu(self, menu_id, title, dynamic=True):
+    def create_application_menu(self, menu_id: str, title: str,
+                                dynamic: bool = True):
         """
         Create a Spyder application menu.
 
@@ -180,11 +197,23 @@ class MainMenu(SpyderPluginV2):
                 lambda menu=menu: set_menu_icons(menu, False))
             menu.aboutToShow.connect(self._hide_options_menus)
 
+        if menu_id in self._ITEM_QUEUE:
+            pending_items = self._ITEM_QUEUE.pop(menu_id)
+            for pending in pending_items:
+                (item, section,
+                 before_item, before_section) = pending
+                self.add_item_to_application_menu(
+                    item, menu_id=menu_id, section=section,
+                    before=before_item, before_section=before_section)
+
         return menu
 
-    def add_item_to_application_menu(self, item, menu=None, menu_id=None,
-                                     section=None, before=None,
-                                     before_section=None):
+    def add_item_to_application_menu(self, item: ItemType,
+                                     menu_id: Optional[str] = None,
+                                     section: Optional[str] = None,
+                                     before: Optional[str] = None,
+                                     before_section: Optional[str] = None,
+                                     omit_id: bool = False):
         """
         Add action or widget `item` to given application menu `section`.
 
@@ -192,33 +221,27 @@ class MainMenu(SpyderPluginV2):
         ----------
         item: SpyderAction or SpyderMenu
             The item to add to the `menu`.
-        menu: ApplicationMenu or None
-            Instance of a Spyder application menu.
         menu_id: str or None
             The application menu unique string identifier.
         section: str or None
             The section id in which to insert the `item` on the `menu`.
-        before: SpyderAction/SpyderMenu or None
-            Make the item appear before another given item.
+        before: str
+            Make the item appear before the given object identifier.
         before_section: Section or None
             Make the item section (if provided) appear before another
             given section.
+        omit_id: bool
+            If True, then the menu will check if the item to add declares an
+            id, False otherwise. This flag exists only for items added on
+            Spyder 4 plugins. Default: False
 
         Notes
         -----
         Must provide a `menu` or a `menu_id`.
         """
-        if menu and menu_id:
-            raise SpyderAPIError('Must provide only menu or menu_id!')
-
-        if menu is None and menu_id is None:
-            raise SpyderAPIError('Must provide at least menu or menu_id!')
-
-        if menu and not isinstance(menu, ApplicationMenu):
-            raise SpyderAPIError('Not an `ApplicationMenu`!')
-
-        if menu_id and menu_id not in self._APPLICATION_MENUS:
-            raise SpyderAPIError('{} is not a valid menu_id'.format(menu_id))
+        if not isinstance(item, (SpyderAction, SpyderMenu)) and not omit_id:
+            raise SpyderAPIError('A menu only accepts items objects of type '
+                                 'SpyderAction or SpyderMenu')
 
         # TODO: For now just add the item to the bottom for non-migrated menus.
         #       Temporal solution while migration is complete
@@ -230,18 +253,96 @@ class MainMenu(SpyderPluginV2):
             ApplicationMenus.Debug: self._main.debug_menu_actions,
         }
 
-        menu_id = menu_id if menu_id else menu.menu_id
-        menu = menu if menu else self.get_application_menu(menu_id)
-
         if menu_id in app_menu_actions:
             actions = app_menu_actions[menu_id]
             actions.append(MENU_SEPARATOR)
             actions.append(item)
         else:
-            menu.add_action(item, section=section, before=before,
-                            before_section=before_section)
+            if menu_id not in self._APPLICATION_MENUS:
+                pending_menu_items = self._ITEM_QUEUE.get(menu_id, [])
+                pending_menu_items.append((item, section, before,
+                                           before_section))
+                self._ITEM_QUEUE[menu_id] = pending_menu_items
+            else:
+                menu = self.get_application_menu(menu_id)
+                menu.add_action(item, section=section, before=before,
+                                before_section=before_section, omit_id=omit_id)
 
-    def get_application_menu(self, menu_id):
+    def remove_application_menu(self, menu_id: str):
+        """
+        Remove a Spyder application menu.
+
+        Parameters
+        ----------
+        menu_id: str
+            The menu unique identifier string.
+        """
+        if menu_id in self._APPLICATION_MENUS:
+            menu = self._APPLICATION_MENUS.pop(menu_id)
+            self.main.menuBar().removeAction(menu.menuAction())
+
+    def remove_item_from_application_menu(self, item_id: str,
+                                          menu_id: Optional[str] = None):
+        """
+        Remove action or widget from given application menu by id.
+
+        Parameters
+        ----------
+        item_id: str
+            The item identifier to remove from the given menu.
+        menu_id: str or None
+            The application menu unique string identifier.
+        """
+        if menu_id not in self._APPLICATION_MENUS:
+            raise SpyderAPIError('{} is not a valid menu_id'.format(menu_id))
+
+        # TODO: For now just add the item to the bottom for non-migrated menus.
+        #       Temporal solution while migration is complete
+        app_menu_actions = {
+            ApplicationMenus.Edit: (
+                self._main.edit_menu_actions, self._main.edit_menu),
+            ApplicationMenus.Search: (
+                self._main.search_menu_actions, self._main.search_menu),
+            ApplicationMenus.Source: (
+                self._main.source_menu_actions, self._main.source_menu),
+            ApplicationMenus.Run: (
+                self._main.run_menu_actions, self._main.run_menu),
+            ApplicationMenus.Debug: (
+                self._main.debug_menu_actions, self._main.debug_menu),
+        }
+
+        app_menus = {
+            ApplicationMenus.Edit: self._main.edit_menu,
+            ApplicationMenus.Search: self._main.search_menu,
+            ApplicationMenus.Source: self._main.source_menu,
+            ApplicationMenus.Run: self._main.run_menu,
+            ApplicationMenus.Debug: self._main.debug_menu
+        }
+
+        menu = self.get_application_menu(menu_id)
+
+        if menu_id in app_menu_actions:
+            actions = app_menu_actions[menu_id]  # type: list
+            menu = app_menus[menu_id]
+            position = None
+            for i, action in enumerate(actions):
+                this_item_id = None
+                if (isinstance(action, SpyderAction) or
+                        hasattr(action, 'action_id')):
+                    this_item_id = action.action_id
+                elif (isinstance(action, SpyderMenu) or
+                        hasattr(action, 'menu_id')):
+                    this_item_id = action.menu_id
+                if this_item_id is not None and this_item_id == item_id:
+                    position = i
+                    break
+            if position is not None:
+                actions.pop(position)
+                menu.remove_action(item_id)
+        else:
+            menu.remove_action(item_id)
+
+    def get_application_menu(self, menu_id: str) -> SpyderMenu:
         """
         Return an application menu by menu unique id.
 
