@@ -23,6 +23,7 @@ import time
 from itertools import islice
 
 # Third party imports
+from qtpy import PYQT5
 from qtpy.compat import getopenfilename, getsavefilename
 from qtpy.QtCore import QByteArray, QProcess, QProcessEnvironment, Qt, Signal
 from qtpy.QtGui import QColor
@@ -33,10 +34,10 @@ from qtpy.QtWidgets import (QApplication, QLabel, QMessageBox, QTreeWidget,
 from spyder.api.translations import get_translation
 from spyder.api.widgets.main_widget import PluginMainWidget
 from spyder.api.widgets.mixins import SpyderWidgetMixin
-from spyder.config.base import get_conf_path
+from spyder.config.base import get_conf_path, running_in_mac_app
 from spyder.plugins.variableexplorer.widgets.texteditor import TextEditor
 from spyder.py3compat import to_text_string
-from spyder.utils.misc import add_pathlist_to_PYTHONPATH, getcwd_or_home
+from spyder.utils.misc import get_python_executable, getcwd_or_home
 from spyder.utils.palette import SpyderPalette, QStylePalette
 from spyder.utils.programs import shell_split
 from spyder.utils.qthelpers import get_item_user_text, set_item_user_text
@@ -53,6 +54,7 @@ logger = logging.getLogger(__name__)
 # ----------------------------------------------------------------------------
 MAIN_TEXT_COLOR = QStylePalette.COLOR_TEXT_1
 
+
 class ProfilerWidgetActions:
     # Triggers
     Browse = 'browse_action'
@@ -86,6 +88,7 @@ class ProfilerWidgetInformationToolbarItems:
     Stretcher2 = 'stretcher_2'
     DateLabel = 'date_label'
 
+
 # --- Utils
 # ----------------------------------------------------------------------------
 def is_profiler_installed():
@@ -147,17 +150,6 @@ class ProfilerWidget(PluginMainWidget):
         Word to select on given row.
     """
 
-    sig_redirect_stdio_requested = Signal(bool)
-    """
-    This signal is emitted to request the main application to redirect
-    standard output/error when using Open/Save/Browse dialogs within widgets.
-
-    Parameters
-    ----------
-    redirect: bool
-        Start redirect (True) or stop redirect (False).
-    """
-
     sig_started = Signal()
     """This signal is emitted to inform the profiling process has started."""
 
@@ -213,7 +205,7 @@ class ProfilerWidget(PluginMainWidget):
         browse_action = self.create_action(
             ProfilerWidgetActions.Browse,
             text='',
-            tip=_('Select Python script'),
+            tip=_('Select Python file'),
             icon=self.create_icon('fileopen'),
             triggered=lambda x: self.select_file(),
         )
@@ -315,8 +307,8 @@ class ProfilerWidget(PluginMainWidget):
         """Kill the profiling process if it is running."""
         if self.process is not None:
             if self.process.state() == QProcess.Running:
-                self.process.kill()
-                self.process.waitForFinished()
+                self.process.close()
+                self.process.waitForFinished(1000)
 
         self.update_actions()
 
@@ -454,9 +446,9 @@ class ProfilerWidget(PluginMainWidget):
             self.sig_redirect_stdio_requested.emit(False)
             filename, _selfilter = getopenfilename(
                 self,
-                _("Select Python script"),
+                _("Select Python file"),
                 getcwd_or_home(),
-                _("Python scripts") + " (*.py ; *.pyw)"
+                _("Python files") + " (*.py ; *.pyw)"
             )
             self.sig_redirect_stdio_requested.emit(True)
 
@@ -530,17 +522,22 @@ class ProfilerWidget(PluginMainWidget):
             lambda ec, es=QProcess.ExitStatus: self._finished(ec, es))
         self.process.finished.connect(self.stop_spinner)
 
+        # Start with system environment
+        proc_env = QProcessEnvironment()
+        for k, v in os.environ.items():
+            proc_env.insert(k, v)
+        proc_env.insert("PYTHONIOENCODING", "utf8")
+        proc_env.remove('PYTHONPATH')
         if pythonpath is not None:
-            env = [to_text_string(_pth)
-                   for _pth in self.process.systemEnvironment()]
-            add_pathlist_to_PYTHONPATH(env, pythonpath)
-            processEnvironment = QProcessEnvironment()
-            for envItem in env:
-                envName, __, envValue = envItem.partition('=')
-                processEnvironment.insert(envName, envValue)
+            proc_env.insert('PYTHONPATH', os.pathsep.join(pythonpath))
+        self.process.setProcessEnvironment(proc_env)
 
-            processEnvironment.insert("PYTHONIOENCODING", "utf8")
-            self.process.setProcessEnvironment(processEnvironment)
+        executable = self.get_conf('executable', section='main_interpreter')
+
+        if not running_in_mac_app(executable):
+            env = self.process.processEnvironment()
+            env.remove('PYTHONHOME')
+            self.process.setProcessEnvironment(env)
 
         self.output = ''
         self.error_output = ''
@@ -559,11 +556,6 @@ class ProfilerWidget(PluginMainWidget):
         if args:
             p_args.extend(shell_split(args))
 
-        executable = sys.executable
-        if executable.endswith("spyder.exe"):
-            # py2exe distribution
-            executable = "python.exe"
-
         self.process.start(executable, p_args)
         running = self.process.waitForStarted()
         if not running:
@@ -577,7 +569,8 @@ class ProfilerWidget(PluginMainWidget):
     def stop(self):
         """Stop the running process."""
         self.running = False
-        self.process.kill()
+        self.process.close()
+        self.process.waitForFinished(1000)
         self.stop_spinner()
         self.update_actions()
 
@@ -620,7 +613,7 @@ class ProfilerWidget(PluginMainWidget):
         self.datelabel.setText(date_text)
 
 
-class TreeWidgetItem( QTreeWidgetItem ):
+class TreeWidgetItem(QTreeWidgetItem):
     def __init__(self, parent=None):
         QTreeWidgetItem.__init__(self, parent)
 
@@ -633,7 +626,7 @@ class TreeWidgetItem( QTreeWidgetItem ):
                 if t0 is not None and t1 is not None:
                     return t0 > t1
 
-            return float( self.text(column) ) > float( otherItem.text(column) )
+            return float(self.text(column)) > float(otherItem.text(column))
         except ValueError:
             return self.text(column) > otherItem.text(column)
 
@@ -663,7 +656,12 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
     sig_edit_goto_requested = Signal(str, int, str)
 
     def __init__(self, parent=None):
-        super().__init__(parent, class_parent=parent)
+        if PYQT5:
+            super().__init__(parent, class_parent=parent)
+        else:
+            QTreeWidget.__init__(self, parent)
+            SpyderWidgetMixin.__init__(self, class_parent=parent)
+
         self.header_list = [_('Function/Module'), _('Total Time'), _('Diff'),
                             _('Local Time'), _('Diff'), _('Calls'), _('Diff'),
                             _('File:line')]
@@ -730,12 +728,12 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
         self.stats1 = stats_indi
         self.stats = stats_indi[0].stats
 
-    def compare(self,filename):
+    def compare(self, filename):
         self.hide_diff_cols(False)
         self.compare_file = filename
 
     def hide_diff_cols(self, hide):
-        for i in (2,4,6):
+        for i in (2, 4, 6):
             self.setColumnHidden(i, hide)
 
     def save_data(self, filename):
@@ -764,7 +762,7 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
 
     def show_tree(self):
         """Populate the tree with profiler data and display it."""
-        self.initialize_view() # Clear before re-populating
+        self.initialize_view()  # Clear before re-populating
         self.setItemsExpandable(True)
         self.setSortingEnabled(False)
         rootkey = self.find_root()  # This root contains profiler overhead
@@ -772,7 +770,7 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
             self.populate_tree(self, self.find_callees(rootkey))
             self.resizeColumnToContents(0)
             self.setSortingEnabled(True)
-            self.sortItems(1, Qt.AscendingOrder) # FIXME: hardcoded index
+            self.sortItems(1, Qt.AscendingOrder)  # FIXME: hardcoded index
             self.change_view(1)
 
     def function_info(self, functionKey):
@@ -866,14 +864,17 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
         return (map(self.color_string, islice(zip(*data), 1, 4)))
 
     def populate_tree(self, parentItem, children_list):
-        """Recursive method to create each item (and associated data) in the tree."""
+        """
+        Recursive method to create each item (and associated data)
+        in the tree.
+        """
         for child_key in children_list:
             self.item_depth += 1
             (filename, line_number, function_name, file_and_line, node_type
              ) = self.function_info(child_key)
 
-            ((total_calls, total_calls_dif), (loc_time, loc_time_dif), (cum_time,
-             cum_time_dif)) = self.format_output(child_key)
+            ((total_calls, total_calls_dif), (loc_time, loc_time_dif),
+             (cum_time, cum_time_dif)) = self.format_output(child_key)
 
             child_item = TreeWidgetItem(parentItem)
             self.item_list.append(child_item)
@@ -884,7 +885,7 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
             child_item.setData(0, Qt.DisplayRole, function_name)
             child_item.setIcon(0, self.icon_list[node_type])
 
-            child_item.setToolTip(1, _('Time in function '\
+            child_item.setToolTip(1, _('Time in function '
                                        '(including sub-functions)'))
             child_item.setData(1, Qt.DisplayRole, cum_time)
             child_item.setTextAlignment(1, Qt.AlignRight)
@@ -893,8 +894,8 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
             child_item.setForeground(2, QColor(cum_time_dif[1]))
             child_item.setTextAlignment(2, Qt.AlignLeft)
 
-            child_item.setToolTip(3, _('Local time in function '\
-                                      '(not in sub-functions)'))
+            child_item.setToolTip(3, _('Local time in function '
+                                       '(not in sub-functions)'))
 
             child_item.setData(3, Qt.DisplayRole, loc_time)
             child_item.setTextAlignment(3, Qt.AlignRight)
@@ -903,7 +904,7 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
             child_item.setForeground(4, QColor(loc_time_dif[1]))
             child_item.setTextAlignment(4, Qt.AlignLeft)
 
-            child_item.setToolTip(5, _('Total number of calls '\
+            child_item.setToolTip(5, _('Total number of calls '
                                        '(including recursion)'))
 
             child_item.setData(5, Qt.DisplayRole, total_calls)
@@ -913,7 +914,7 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
             child_item.setForeground(6, QColor(total_calls_dif[1]))
             child_item.setTextAlignment(6, Qt.AlignLeft)
 
-            child_item.setToolTip(7, _('File:line '\
+            child_item.setToolTip(7, _('File:line '
                                        'where function is defined'))
             child_item.setData(7, Qt.DisplayRole, file_and_line)
             #child_item.setExpanded(True)
@@ -954,11 +955,13 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
 
     def get_top_level_items(self):
         """Iterate over top level items"""
-        return [self.topLevelItem(_i) for _i in range(self.topLevelItemCount())]
+        return [self.topLevelItem(_i)
+                for _i in range(self.topLevelItemCount())]
 
     def get_items(self, maxlevel):
         """Return all items with a level <= `maxlevel`"""
         itemlist = []
+
         def add_to_itemlist(item, maxlevel, level=1):
             level += 1
             for index in range(item.childCount()):
@@ -966,6 +969,7 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
                 itemlist.append(citem)
                 if level <= maxlevel:
                     add_to_itemlist(citem, maxlevel, level)
+
         for tlitem in self.get_top_level_items():
             itemlist.append(tlitem)
             if maxlevel > 0:
@@ -973,13 +977,13 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
         return itemlist
 
     def change_view(self, change_in_depth):
-        """Change the view depth by expand or collapsing all same-level nodes"""
+        """Change view depth by expanding or collapsing all same-level nodes"""
         self.current_view_depth += change_in_depth
         if self.current_view_depth < 0:
             self.current_view_depth = 0
         self.collapseAll()
         if self.current_view_depth > 0:
-            for item in self.get_items(maxlevel=self.current_view_depth-1):
+            for item in self.get_items(maxlevel=self.current_view_depth - 1):
                 item.setExpanded(True)
 
 
@@ -991,25 +995,25 @@ def primes(n):
     Simple test function
     Taken from http://www.huyng.com/posts/python-performance-analysis/
     """
-    if n==2:
+    if n == 2:
         return [2]
-    elif n<2:
+    elif n < 2:
         return []
-    s=list(range(3,n+1,2))
+    s = list(range(3, n + 1, 2))
     mroot = n ** 0.5
-    half=(n+1)//2-1
-    i=0
-    m=3
+    half = (n + 1) // 2 - 1
+    i = 0
+    m = 3
     while m <= mroot:
         if s[i]:
-            j=(m*m-3)//2
-            s[j]=0
-            while j<half:
-                s[j]=0
-                j+=m
-        i=i+1
-        m=2*i+3
-    return [2]+[x for x in s if x]
+            j = (m * m - 3) // 2
+            s[j] = 0
+            while j < half:
+                s[j] = 0
+                j += m
+        i = i + 1
+        m = 2 * i + 3
+    return [2] + [x for x in s if x]
 
 
 def test():
@@ -1033,6 +1037,8 @@ def test():
     widget = ProfilerWidget('test', plugin=plugin_mock)
     widget._setup()
     widget.setup()
+    widget.get_conf('executable', get_python_executable(),
+                    section='main_interpreter')
     widget.resize(800, 600)
     widget.show()
     widget.analyze(script)
