@@ -12,14 +12,16 @@ import sys
 
 # Third-party imports
 import qdarkstyle
-import qstylizer
 from qstylizer.parser import parse as parse_stylesheet
+import qstylizer.style
 
 # Local imports
 from spyder.config.gui import OLD_PYQT
 from spyder.utils.palette import QStylePalette
 
 
+MAC = sys.platform == 'darwin'
+
 # =============================================================================
 # ---- Base stylesheet class
 # =============================================================================
@@ -47,10 +49,14 @@ class SpyderStyleSheet:
     def set_stylesheet(self):
         raise NotImplementedError(
             "Subclasses need to implement this method to set the _stylesheet "
-            "attribute as a Qstylizer StyleSheet object"
+            "attribute as a Qstylizer StyleSheet object."
         )
 
     def __str__(self):
+        """
+        Get a string representation of the stylesheet object this class
+        holds.
+        """
         return self.to_string()
 
 
@@ -170,6 +176,15 @@ class AppStylesheet(SpyderStyleSheet):
                 backgroundColor=color
             )
 
+        # Adjust padding of QPushButton's in QDialog's
+        css["QDialog QPushButton"].setValues(
+            padding='3px 15px 3px 15px',
+        )
+
+        css["QDialogButtonBox QPushButton:!default"].setValues(
+            padding='3px 0px 3px 0px',
+        )
+
 
 APP_STYLESHEET = AppStylesheet()
 
@@ -211,6 +226,11 @@ class ApplicationToolbarStylesheet(SpyderStyleSheet):
                 backgroundColor=color
             )
 
+        # Remove indicator for popup mode
+        css['QToolBar QToolButton::menu-indicator'].setValues(
+            image='none'
+        )
+
 
 class PanesToolbarStyleSheet(SpyderStyleSheet):
     """Stylesheet for pane toolbars."""
@@ -229,8 +249,10 @@ class PanesToolbarStyleSheet(SpyderStyleSheet):
             height=self.BUTTON_HEIGHT,
             width=self.BUTTON_WIDTH,
             border='0px',
+            margin='0px'
         )
 
+        # Remove indicator for popup mode
         css['QToolButton::menu-indicator'].setValues(
             image='none'
         )
@@ -255,6 +277,12 @@ class PanesTabBarStyleSheet(PanesToolbarStyleSheet):
         css = self.get_stylesheet()
         is_macos = sys.platform == 'darwin'
 
+        # This removes a white dot that appears to the left of right corner
+        # widgets
+        css.QToolBar.setValues(
+            marginLeft='-1px',
+        )
+
         # QTabBar forces the corner widgets to be smaller than they should.
         # be. The added top margin allows the toolbuttons to expand to their
         # normal size.
@@ -267,6 +295,16 @@ class PanesTabBarStyleSheet(PanesToolbarStyleSheet):
             paddingRight='10px' if is_macos else '4px'
         )
 
+        # Show tabs left-aligned on Mac
+        if MAC:
+            css.QTabBar.setValues(
+                alignment='left'
+            )
+
+            css['QTabWidget::tab-bar'].setValues(
+                alignment='left'
+            )
+
         # Fix minor visual glitch when hovering tabs
         # See spyder-ide/spyder#15398
         css['QTabBar::tab:hover'].setValues(
@@ -328,19 +366,21 @@ class PanesTabBarStyleSheet(PanesToolbarStyleSheet):
         css['QTabWidget::right-corner'].setValues(
             top='-1px',
             bottom='-2px',
-            right='1px'
+            right='-1px'
         )
 
-    def to_string(self):
-        css_string = self._stylesheet.toString()
-
-        # TODO: We need to fix this in qstylizer
-        if sys.platform == 'darwin':
-            left_tabs = ("QTabWidget::tab-bar {alignment: left;}\n"
-                         "QTabBar {alignment: left;}")
-            css_string = css_string + left_tabs
-
-        return css_string
-
 
 PANES_TABBAR_STYLESHEET = PanesTabBarStyleSheet()
+
+
+# =============================================================================
+# ---- Style for special dialogs
+# =============================================================================
+class DialogStyle:
+    """Style constants for tour, about and kite dialogs."""
+
+    IconScaleFactor = 0.5
+    TitleFontSize = '19pt' if MAC else '14pt'
+    ContentFontSize = '15pt' if MAC else '12pt'
+    ButtonsFontSize = '15pt' if MAC else '13pt'
+    ButtonsPadding = '6px' if MAC else '4px 10px'
